import os
import webview
import socket
import time
import subprocess
import threading
import logging
import re
import argparse


VERSION = "1.0.0"


# Configure logging
logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(message)s')

current_url = './web/index.html'  # Variable to track the current URL
ping_results = []  # Array to store the ping results
disconnection_count = 0  # Counter for the number of internet cuts

def toggle_fullscreen(window):
    # Wait a few seconds before toggle fullscreen
    window.toggle_fullscreen()

def parse_ping_output(output):
    # Use regex to find the time=XXXms part of the ping output
    match = re.search(r'time=(\d+\.?\d*) ms', output)
    if match:
        return float(match.group(1))
    return None

def check_internet_connection(window):
    global current_url, ping_results, disconnection_count
    start_time = time.time()  # Record the start time for 24-hour tracking

    while True:
        logging.info("Checking internet connection...")

        # Ping 1.1.1.1 twice with a timeout of 1 second
        response = subprocess.run(['ping', '1.1.1.1', '-c', '2', '-W', '1'], stdout=subprocess.PIPE)
        output = response.stdout.decode('utf-8')
        
        if response.returncode == 0:
            # Extract the response time
            response_time = parse_ping_output(output)
            if response_time is not None:
                logging.info(f"Ping successful with response time: {response_time} ms")
                ping_results.append(('yes', response_time, disconnection_count))
            else:
                logging.info("Ping successful but response time could not be determined.")
                ping_results.append(('yes', None, disconnection_count))

            # If ping is successful and "nointernet.html" was shown, reload the main window
            if current_url == './web/nointernet.html':
                logging.info("Reconnected to the internet. Reloading main window...")
                current_url = './web/index.html'
                window.load_url(current_url)
        else:
            logging.warning("Ping failed. No internet connection.")
            disconnection_count += 1  # Increment the disconnection count
            ping_results.append(('no', None, disconnection_count))
            # If ping fails, load "nointernet.html"
            if current_url != './web/nointernet.html':
                logging.info("Loading nointernet.html...")
                current_url = './web/nointernet.html'
                window.load_url(current_url)

        # Reset disconnection count every 24 hours
        if time.time() - start_time >= 86400:  # 86400 seconds in 24 hours
            disconnection_count = 0
            start_time = time.time()  # Reset the start time

        time.sleep(5)

if __name__ == '__main__':
    # Parse command-line arguments
    parser = argparse.ArgumentParser(description='QinayaCloudPro')
    parser.add_argument('-v', '--version', action='store_true', help='show version number and exit')
    args = parser.parse_args()

    # Show version and exit if the version flag is provided
    if args.version:
        print(f"QinayaCloudPro Version: {VERSION}")
        exit(0)

    # Get the OS hostname
    hostname = socket.gethostname()
    logging.info(f"Hostname: {hostname}")

    
    # Create a non-resizable webview window in fullscreen mode
    window = webview.create_window('QinayaCloudPro', current_url)

    # Start the internet connection check in a separate thread
    internet_thread = threading.Thread(target=check_internet_connection, args=(window,))
    internet_thread.daemon = True
    internet_thread.start()

    # Start the webview
    webview.start(toggle_fullscreen, window, debug=False, private_mode=False, http_port=9876)
