import os
import socket
import psutil
import json
import requests
import time
from datetime import datetime
import platform

def get_connection_type():
    if os.name == 'nt':  # Windows
        if psutil.net_if_stats()['Wi-Fi'].isup:
            return 'wifi'
        else:
            return 'ethernet'
    else:  # Unix-like (Linux, macOS)
        try:
            connections = psutil.net_if_addrs()
            for interface in connections:
                if 'wlan' in interface or 'wifi' in interface:
                    return 'wifi'
            return 'ethernet'
        except Exception as e:
            return 'unknown'

def get_ip_address():
    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    try:
        # connect() for UDP doesn't send packets
        s.connect(("8.8.8.8", 80))
        return s.getsockname()[0]
    except Exception as e:
        return "unknown"
    finally:
        s.close()

def get_battery_status():
    if psutil.sensors_battery():
        battery = psutil.sensors_battery()
        return battery.percent
    return "No battery"

def get_cpu_usage():
    return psutil.cpu_percent(interval=1)

def get_ram_usage():
    memory = psutil.virtual_memory()
    return memory.total, memory.used

def get_network_usage():
    net_io = psutil.net_io_counters()
    return net_io.bytes_sent, net_io.bytes_recv

def collect_stats():
    hostname = socket.gethostname()
    ip_address = get_ip_address()
    connection_type = get_connection_type()
    battery_level = get_battery_status()
    cpu_usage = get_cpu_usage()
    total_ram, used_ram = get_ram_usage()
    net_sent, net_recv = get_network_usage()

    stats = {
        "hostname": hostname,
        "ip_address": ip_address,
        "connection_type": connection_type,
        "battery_level": battery_level,
        "cpu_usage_percent": cpu_usage,
        "total_ram_bytes": total_ram,
        "used_ram_bytes": used_ram,
        "network_bytes_sent": net_sent,
        "network_bytes_recv": net_recv,
        "timestamp": datetime.now().isoformat()
    }

    return stats

def send_stats(stats):
    url = "https://panel.qinaya.co/clients/stats"
    headers = {'Content-Type': 'application/json'}
    try:
        response = requests.post(url, data=json.dumps(stats), headers=headers)
        if response.status_code == 200:
            print("Stats successfully sent.")
        else:
            print(f"Failed to send stats. Status code: {response.status_code}")
    except Exception as e:
        print(f"Error sending stats: {e}")

if __name__ == "__main__":
    stats = collect_stats()
    json_stats = json.dumps(stats, indent=4)
    
    # Print stats to the console for debugging
    print("Collected Stats:")
    print(json_stats)

    # Save stats to a JSON file
    with open('stats.json', 'w') as f:
        f.write(json_stats)
    
    # Send stats to the server
    send_stats(stats)
    
    # Schedule the script to run every hour using cron or task scheduler
    # This part is system-dependent and is not included in the script itself.
